@@ -14,6 +14,7 @@ def plotting_context(
     ax: Optional[matplotlib.axes.Axes] = None,  # type: ignore
     pause: bool = True,
     title: str = "",
+    aspect: bool = False,
     filename: str = "",
     render: bool = True,
     axis_index: Optional[Union[int, Tuple[int]]] = None,
@@ -26,6 +27,8 @@ def plotting_context(
         closed. If set to false, the script continues immediately after the window is
         rendered.
     :param title: Plot title
+    :param aspect: If set to True, the axes of the figure are set to an equal aspect
+        ratio
     :param filename: Pass a non-empty string or path to save the image as. If
         this option is used, the figure is closed after the file is saved.
     :param render: If set to False, the image is not displayed. This may be useful
@@ -53,7 +56,7 @@ def plotting_context(
 
         try:
             if axis_index is None:
-                axis_index = (0,) * ax.ndim
+                axis_index = (0,) * ax.ndim  # type: ignore
             ax = ax[axis_index]  # type: ignore
         except (AttributeError, TypeError):
             pass  # only 1 axis, not an array
@@ -78,6 +81,9 @@ def plotting_context(
     # if no axes was supplied, finish the plot and return the figure and axes
     plt.tight_layout()
 
+    if aspect:
+        ax.set_aspect("equal", anchor="C")  # type: ignore
+
     if filename:
         fig.savefig(filename, dpi=fig.dpi)
         plt.close(fig)  # close the figure to free the memory
