@@ -55,10 +55,14 @@ class GrossProperties:
     # first moments of area
     e_qx: float = 0
     e_qy: float = 0
+    qx_gross: float = 0
+    qy_gross: float = 0
 
     # centroids
     cx: float = 0
     cy: float = 0
+    cx_gross: float = 0
+    cy_gross: float = 0
 
     # second moments of area
     e_ixx_g: float = 0
@@ -116,6 +120,8 @@ class GrossProperties:
         table.add_row("E.Qy", "{:>{fmt}}".format(self.e_qy, fmt=fmt))
         table.add_row("x-Centroid", "{:>{fmt}}".format(self.cx, fmt=fmt))
         table.add_row("y-Centroid", "{:>{fmt}}".format(self.cy, fmt=fmt))
+        table.add_row("x-Centroid (Gross)", "{:>{fmt}}".format(self.cx_gross, fmt=fmt))
+        table.add_row("y-Centroid (Gross)", "{:>{fmt}}".format(self.cy_gross, fmt=fmt))
         table.add_row("E.Ixx_g", "{:>{fmt}}".format(self.e_ixx_g, fmt=fmt))
         table.add_row("E.Iyy_g", "{:>{fmt}}".format(self.e_iyy_g, fmt=fmt))
         table.add_row("E.Ixy_g", "{:>{fmt}}".format(self.e_ixy_g, fmt=fmt))
@@ -408,6 +414,9 @@ class MomentCurvatureResults:
     :param m_xy: List of resultant bending moments
     :param failure_geometry: Geometry object of the region of the cross-section that
         failed, ending the moment curvature analysis
+    :param convergence: The critical ratio between the strain and the failure strain
+        within the cross-section for each curvature step in the analysis. A value of one
+        indicates failure.
     """
 
     # results
@@ -418,12 +427,15 @@ class MomentCurvatureResults:
     m_y: List[float] = field(default_factory=list)
     m_xy: List[float] = field(default_factory=list)
     failure_geometry: CPGeom = field(init=False)
+    convergence: List[float] = field(default_factory=list)
 
     # for analysis
+    _kappa: float = field(default=0, repr=False)
     _n_i: float = field(default=0, repr=False)
     _m_x_i: float = field(default=0, repr=False)
     _m_y_i: float = field(default=0, repr=False)
     _failure: bool = field(default=False, repr=False)
+    _failure_convergence: float = field(default=0, repr=False)
 
     def plot_results(
         self,
@@ -547,7 +559,7 @@ class MomentCurvatureResults:
         return float(f_kappa(moment))
 
 
-@dataclass
+@dataclass(order=True)
 class UltimateBendingResults:
     r"""Class for storing ultimate bending results.
 
@@ -576,7 +588,7 @@ class UltimateBendingResults:
     m_xy: float = 0
 
     # label
-    label: Optional[str] = None
+    label: Optional[str] = field(default=None, compare=False)
 
     def print_results(
         self,
@@ -617,6 +629,20 @@ class MomentInteractionResults:
 
     results: List[UltimateBendingResults] = field(default_factory=list)
 
+    def sort_results(self) -> None:
+        """Sorts the results by decreasing axial force."""
+
+        self.results.sort(reverse=True)
+
+        # remove duplicates from sorted list
+        new_results = []
+
+        for res in self.results:
+            if res not in new_results:
+                new_results.append(res)
+
+        self.results = new_results
+
     def get_results_lists(
         self,
         moment: str,
@@ -969,11 +995,11 @@ class BiaxialBendingResults:
             m_x_list = np.array(m_x_list) * m_scale
             m_y_list = np.array(m_y_list) * m_scale
 
-            ax.plot3D(m_x_list, m_y_list, n_list, fmt)
+            ax.plot3D(m_x_list, m_y_list, n_list, fmt)  # type: ignore
 
         ax.set_xlabel("Bending Moment $M_x$")
         ax.set_ylabel("Bending Moment $M_y$")
-        ax.set_zlabel("Axial Force $N$")
+        ax.set_zlabel("Axial Force $N$")  # type: ignore
         plt.show()
 
         return ax
@@ -1065,6 +1091,7 @@ class StressResult:
 
         with plotting_context(
             title=title,
+            aspect=True,
             **dict(
                 kwargs, nrows=1, ncols=3, gridspec_kw={"width_ratios": [1, 0.08, 0.08]}
             ),
@@ -1153,7 +1180,7 @@ class StressResult:
                     # plot the filled contour
                     trictr_conc = fig.axes[0].tricontourf(
                         triang_conc, sig, v_conc, cmap=cmap_conc, norm=CenteredNorm()
-                    )
+                    )  # type: ignore
 
                     # plot a zero stress contour, supressing warning
                     with warnings.catch_warnings():
@@ -1185,7 +1212,7 @@ class StressResult:
                             [zero_level],
                             linewidths=1,
                             linestyles="dashed",
-                        )
+                        )  # type: ignore
 
             # plot the meshed reinforcement stresses
             trictr_reinf = None
@@ -1203,7 +1230,7 @@ class StressResult:
                     # plot the filled contour
                     trictr_reinf = fig.axes[0].tricontourf(
                         triang_reinf, sig, v_reinf, cmap=cmap_reinf, norm=CenteredNorm()
-                    )
+                    )  # type: ignore
 
                     # plot a zero stress contour, supressing warning
                     with warnings.catch_warnings():
@@ -1235,7 +1262,7 @@ class StressResult:
                             [zero_level],
                             linewidths=1,
                             linestyles="dashed",
-                        )
+                        )  # type: ignore
 
             # plot the lumped reinforcement stresses
             lumped_reinf_patches = []
@@ -1252,10 +1279,10 @@ class StressResult:
             patch = PatchCollection(lumped_reinf_patches, cmap=cmap_reinf)
             patch.set_array(colours)
             if reinf_tick_same:
-                patch.set_clim([0.99 * v_reinf[0], 1.01 * v_reinf[-1]])
+                patch.set_clim(vmin=0.99 * v_reinf[0], vmax=1.01 * v_reinf[-1])
             else:
-                patch.set_clim([v_reinf[0], v_reinf[-1]])
-            fig.axes[0].add_collection(patch)
+                patch.set_clim(vmin=v_reinf[0], vmax=v_reinf[-1])
+            fig.axes[0].add_collection(patch)  # type: ignore
 
             # add the colour bars
             fig.colorbar(
@@ -1279,8 +1306,6 @@ class StressResult:
                 cax=fig.axes[2],
             )
 
-            ax.set_aspect("equal", anchor="C")  # type: ignore
-
         return ax
 
     def sum_forces(
