@@ -21,7 +21,7 @@ def get_service_strain(
     theta: float,
     kappa: float,
 ) -> float:
-    r"""Determines the strain at point `point` given curvcature `kappa` and neutral axis
+    r"""Determines the strain at point `point` given curvature `kappa` and neutral axis
     angle `theta`. Positive strain is compression.
 
     :param point: Point at which to evaluate the strain
@@ -276,9 +276,9 @@ def gauss_points(
         return [[0.5, 1.0 / 3, 1.0 / 3]]
     elif n == 3:
         return [
-            [1.0 / 6, 0, 0.5],
-            [1.0 / 6, 0.5, 0],
-            [1.0 / 6, 0.5, 0.5],
+            [1.0 / 6, 1.0 / 6, 1.0 / 6],
+            [1.0 / 6, 2.0 / 3, 1.0 / 6],
+            [1.0 / 6, 1.0 / 6, 2.0 / 3],
         ]
     else:
         raise ValueError(f"{n} gauss points not implemented.")
@@ -451,3 +451,7 @@ def create_unknown_progress() -> Progress:
         CustomTimeElapsedColumn(),
         expand=True,
     )
+
+
+class AnalysisError(Exception):
+    pass
